@@ -63,7 +63,9 @@
 #include "storage/ipc.h"
 #include "tcop/tcopprot.h"
 #include "utils/array.h"
+
 #include "utils/builtins.h"
+
 #if PG_VERSION_NUM >= 80500
 #include "utils/bytea.h"
 #endif
@@ -127,8 +129,17 @@ extern int R_SignalHandlers;
 #undef WARNING
 #endif
 
+#ifdef PGWARNING
+#define WARNING		PGWARNING
+#else
 #define WARNING		19
+#endif
+
+#ifdef PGERROR
+#define ERROR		PGERROR
+#else
 #define ERROR		20
+#endif
 
 /* starting in R-2.7.0 this defn was removed from Rdevices.h */
 #ifndef KillAllDevices
@@ -385,13 +396,13 @@ extern void R_RunExitFinalizers(void);
 		HeapTupleHeaderSetTypMod(dtrigtup, tupdesc->tdtypmod); \
 		SET_ARG(PointerGetDatum(dtrigtup),false,7); \
 	} while (0)
-#define CONVERT_TUPLE_TO_DATAFRAME \
+#define CONVERT_TUPLE_TO_DATAFRAME(tt) \
 	do { \
 		Oid			tupType; \
 		int32		tupTypmod; \
 		TupleDesc	tupdesc; \
 		HeapTuple	tuple = palloc(sizeof(HeapTupleData)); \
-		HeapTupleHeader	tuple_hdr = DatumGetHeapTupleHeader(GET_ARG_VALUE(i)); \
+		HeapTupleHeader	tuple_hdr = DatumGetHeapTupleHeader(tt); \
 		tupType = HeapTupleHeaderGetTypeId(tuple_hdr); \
 		tupTypmod = HeapTupleHeaderGetTypMod(tuple_hdr); \
 		tupdesc = lookup_rowtype_tupdesc(tupType, tupTypmod); \
@@ -539,6 +550,10 @@ PGDLLEXPORT void plr_SPI_cursor_close(SEXP cursor_in);
 PGDLLEXPORT void plr_SPI_cursor_move(SEXP cursor_in, SEXP forward_in, SEXP rows_in);
 PGDLLEXPORT SEXP plr_SPI_lastoid(void);
 PGDLLEXPORT void throw_r_error(const char **msg);
+#if PG_VERSION_NUM >= 110000
+PGDLLEXPORT SEXP plr_SPI_commit(void);
+PGDLLEXPORT SEXP plr_SPI_rollback(void);
+#endif
 
 /* Postgres callable functions useful in conjunction with PL/R */
 PGDLLEXPORT Datum plr_version(PG_FUNCTION_ARGS);
